@@ -1,24 +1,24 @@
-##' Clear packages and temporary files  from repo build process
-##'
-##' These are convenience functions which clears the intermediate
-##' files generated during the build process. This is important
-##' when, e.g., building a repository for the first time with
-##' a new version of R.
-##'
-##' @details \code{clear_repo} removes packages deployed into the destination repository,
-##' updates the PACKAGES and PACKAGES.gz files, and resets the build results within the
-##' GRANRepository object. \code{clear_temp_fils} clears
-##' intermediate files from the library location used during building, the temporary
-##' repository, the package staging area, and the store of install- and check-results.
-##'
-##' @param repo GRANRepository - The repository to clean
-##' @param checkout logical - Should the checkouts of packages also be cleared.
-##' Generally this is not necessary (default: FALSE)
-##'
-##' @return The GRANRepository object, ready to be rebuilt.
-##' @author Gabriel Becker
-##' @rdname clear
-##' @export
+#' Clear packages and temporary files  from repo build process
+#'
+#' These are convenience functions which clears the intermediate
+#' files generated during the build process. This is important
+#' when, e.g., building a repository for the first time with
+#' a new version of R.
+#'
+#' @details \code{clear_repo} removes packages deployed into the destination repository,
+#' updates the PACKAGES and PACKAGES.gz files, and resets the build results within the
+#' GRANRepository object. \code{clear_temp_fils} clears
+#' intermediate files from the library location used during building, the temporary
+#' repository, the package staging area, and the store of install- and check-results.
+#'
+#' @param repo GRANRepository - The repository to clean
+#' @param checkout logical - Should the checkouts of packages also be cleared.
+#' Generally this is not necessary (default: FALSE)
+#'
+#' @return The GRANRepository object, ready to be rebuilt.
+#' @author Gabriel Becker
+#' @rdname clear
+#' @export
 clear_temp_fils = function(repo, checkout = FALSE) {
     dirs = c( "temporary library" = temp_lib(repo),
         "temporary repo" = temp_repo(repo),
@@ -32,10 +32,10 @@ clear_temp_fils = function(repo, checkout = FALSE) {
     if(!all(res))
         warning("Not all clearing steps succeeded. See the relevant GRAN log for more information")
     repo
-}    
-    
-    
-        
+}
+
+
+
 .clearhelper = function(dir, repo, dirlab) {
     fils = list.files(dir, include.dirs=TRUE, no..=TRUE, full.names=TRUE)
     if(!file.exists(dir) || !length(fils)) {
@@ -53,14 +53,14 @@ clear_temp_fils = function(repo, checkout = FALSE) {
     all(res==0)
 }
 
-##' @rdname clear
-##' @param all logical - Should temporary artifacts from the build process also be cleared
-##' (via automatically calling clear_temp_fils). Defaults to TRUE
-##' @param archivedir character - Optional. A directory where build packages
-##' deployed to the repository will be archived. Package versions already in
-##' the archive will not be overwritten. Defaults to NULL (no archiving).
-##' @export
-clear_repo = function(repo, all = TRUE, checkout = FALSE, archivedir = NULL) {
+#' @rdname clear
+#' @param all logical - Should temporary artifacts from the build process also be cleared
+#' (via automatically calling clear_temp_fils). Defaults to TRUE
+#' @param archivedir character - Optional. A directory where build packages
+#' deployed to the repository will be archived. Package versions already in
+#' the archive will not be overwritten. Defaults to repobase(repo)/"Archive".
+#' @export
+clear_repo = function(repo, all = TRUE, checkout = FALSE, archivedir = file.path(repobase(repo), "Archive")) {
     if(all)
         res = clear_temp_fils(repo = repo, checkout = checkout)
     else
@@ -69,7 +69,7 @@ clear_repo = function(repo, all = TRUE, checkout = FALSE, archivedir = NULL) {
     if(!is.null(archivedir)) {
         if(!file.exists(archivedir))
             dir.create(archivedir)
-        
+
         fils = list.files(d, pattern = builtPkgExt(), full.names=TRUE)
         logfun(repo)("NA", sprintf("Found %d deployed packages. Copying to archive before clearing repository.", length(fils)))
         file.copy(fils, archivedir, overwrite = FALSE)
